==> jboss-3.2.6-src.tar.bz2: jboss-3.2.6-src/jaxrpc/src/main/org/apache/axis/InternalException.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.axis;

import org.apache.axis.components.logger.LogFactory;
import org.apache.axis.utils.Messages;
import org.apache.commons.logging.Log;

/**
 * Encapsulates exceptions for "should never occur" situations.  Extends
 * RuntimeException so it need not explicitly be caught.  Logs the exception
 * as a fatal error, and if debug is enabled, includes the full stack trace.
 *
 * @author Sam Ruby (rubys@us.ibm.com)
 * @author Glyn Normington (glyn_normington@uk.ibm.com)
 */
public class InternalException extends RuntimeException
{

   private static Log log =
           LogFactory.getLog(InternalException.class.getName());

   /**
    * Attribute which controls whether or not logging of such events should
    * occur.  Default is true and is recommended.  Sometimes this may be
    * turned off in unit tests when internal errors are intentionally
    * provoked.
    */
   private static boolean shouldLog = true;

   /**
    * Setter for logging.
    */
   public static void setLogging(boolean logging)
   {
      shouldLog = logging;
   }

   /**
    * Getter for logging property.
    */
   public static boolean getLogging()
   {
      return shouldLog;
   }

   /**
    * Construct an Internal Exception from a String.  The string is wrapped
    * in an exception, enabling a stack traceback to be obtained.
    *
    * @param message String form of the error
    */
   public InternalException(String message)
   {
      this(new Exception(message));
   }

   /**
    * Construct an Internal Exception from an Exception.
    *
    * @param exception original exception which was unexpected
    */
   public InternalException(Exception e)
   {
      super(e.toString());

      if (shouldLog)
      {
         // if the exception is merely bubbling up the stack, only log the
         // event if debug is turned on.
         if (e instanceof InternalException)
         {
            log.debug("InternalException: ", e);
         }
         else
         {
            log.fatal(Messages.getMessage("exception00"), e);
         }
      }
   }
}

==> jboss-3.2.7-src.tar.bz2: jboss-3.2.7-src/jaxrpc/src/main/org/apache/axis/InternalException.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.axis;

import org.apache.axis.utils.Messages;
import org.jboss.logging.Logger;

/**
 * Encapsulates exceptions for "should never occur" situations.  Extends
 * RuntimeException so it need not explicitly be caught.  Logs the exception
 * as a fatal error, and if debug is enabled, includes the full stack trace.
 *
 * @author Sam Ruby (rubys@us.ibm.com)
 * @author Glyn Normington (glyn_normington@uk.ibm.com)
 */
public class InternalException extends RuntimeException
{

   private static Logger log = Logger.getLogger(InternalException.class.getName());

   /**
    * Attribute which controls whether or not logging of such events should
    * occur.  Default is true and is recommended.  Sometimes this may be
    * turned off in unit tests when internal errors are intentionally
    * provoked.
    */
   private static boolean shouldLog = true;

   /**
    * Setter for logging.
    */
   public static void setLogging(boolean logging)
   {
      shouldLog = logging;
   }

   /**
    * Getter for logging property.
    */
   public static boolean getLogging()
   {
      return shouldLog;
   }

   /**
    * Construct an Internal Exception from a String.  The string is wrapped
    * in an exception, enabling a stack traceback to be obtained.
    *
    * @param message String form of the error
    */
   public InternalException(String message)
   {
      this(new Exception(message));
   }

   /**
    * Construct an Internal Exception from an Exception.
    *
    * @param exception original exception which was unexpected
    */
   public InternalException(Exception e)
   {
      super(e.toString());

      if (shouldLog)
      {
         // if the exception is merely bubbling up the stack, only log the
         // event if debug is turned on.
         if (e instanceof InternalException)
         {
            log.debug("InternalException: ", e);
         }
         else
         {
            log.fatal(Messages.getMessage("exception00"), e);
         }
      }
   }
}
